{if $itemcount > 0}
<table cellspacing="0" class="pagetable">
	<thead>
		<tr>
			<th>{$datatext}</th>
			<th>{$authortext}</th>
			<th>{$pageidtext}</th>
			<th>{$postdatetext}</th>
			<th>{$modifydatetext}</th>
			<th class="pageicon">&nbsp;</th>
			<th class="pageicon">&nbsp;</th>
		</tr>
	</thead>
	<tbody>
	{foreach from=$items item=entry}
		<tr class="{$entry->rowclass}" onmouseover="this.className='{$entry->rowclass}hover';" onmouseout="this.className='{$entry->rowclass}';">
			<td>{$entry->data}</td>
			<td>{$entry->author}</td>
			<td><a target="_blank" href="../index.php?page={$entry->pageid}" title="Click to open the page">{$entry->pageid}</a></td>
			<td>{$entry->postdate}</td>
			<td>{$entry->modifydate}</td>
			<td>{$entry->editlink}</td>
			<td>{$entry->deletelink}</td>
		</tr>
	{/foreach}
	</tbody>
</table>
{/if}
