{$startform}
	<div class="pageoverflow">
		<p class="pagetext">*{$authortext}:</p>
		<p class="pageinput">{$inputauthor}</p>
	</div>
	<div class="pageoverflow">
		<p class="pagetext">*{$datatext}:</p>
		<p class="pageinput">{$inputdata}</p>
	</div>
	<div class="pageoverflow">
		<p class="pagetext">{$pageidtext}:</p>
		<p class="pageinput">{$inputpageid}</p>
	</div>
	<div class="pageoverflow">
		<p class="pagetext">{$postdatetext}:</p>
		<p class="pageinput">{$inputpostdate}</p>
	</div>
	<div class="pageoverflow">
		<p class="pagetext">{$createdatetext}:</p>
		<p class="pageinput">{$inputcreatedate}</p>
	</div>
	<div class="pageoverflow">
		<p class="pagetext">{$modifydatetext}:</p>
		<p class="pageinput">{$inputmodifydate}</p>
	</div>
	<div class="pageoverflow">
		<p class="pagetext">&nbsp;</p>
		<p class="pageinput">{$hidden}{$submit}{$cancel}</p>
	</div>
{$endform}
